# Telefly
Create Telegram bots in Python.


### Important
> This package was only created for [OYSA](https://github.com/ztpnk/oysa). It will not be further developed or maintained but stays online for understanding the OYSA-Code. Look at [pythin-telegram-bot](https://github.com/python-telegram-bot/python-telegram-bot/) for a python telegram bot wrapper.


## Features
- Simple to use
- Very lightweight

## Usage

```bash
$ pip install telefly
```

```python
from telefly import telefly


tf = telefly(TOKEN)

tf.sendMessage(MESSAGE, chatID)

```
